searchData={"items":[{"type":"module","doc":"![GitHub CI](https://github.com/rodloboz/mistral/actions/workflows/all-checks-pass.yml/badge.svg)\n\n[![License: MIT](https://img.shields.io/badge/License-MIT-yellow.svg)](https://opensource.org/licenses/MIT)\n\nClient for the Mistral AI API.\n\nThis library provides a simple and convenient way to integrate with Mistral's\nAPI, allowing you to use their powerful language models in your Elixir applications.","title":"Mistral","ref":"Mistral.html"},{"type":"module","doc":"Add `mistral` to your list of dependencies in `mix.exs`:\n\n```elixir\ndef deps do\n  [\n    {:mistral, \"~> 0.2.0\"}\n  ]\nend\n```","title":"Installation - Mistral","ref":"Mistral.html#module-installation"},{"type":"module","doc":"Set your Mistral API key in your config:\n\n```elixir\nconfig :mistral, :api_key, \"your_mistral_api_key\"\n```","title":"Configuration - Mistral","ref":"Mistral.html#module-configuration"},{"type":"module","doc":"","title":"Usage Examples - Mistral","ref":"Mistral.html#module-usage-examples"},{"type":"module","doc":"```elixir\n{:ok, client} = Mistral.init(\"your_api_key\")\n\n{:ok, response} = Mistral.chat(client,\n  model: \"mistral-small-latest\",\n  messages: [\n    %{role: \"user\", content: \"Write a haiku about elixir\"}\n  ]\n)\n```","title":"Chat Completion - Mistral","ref":"Mistral.html#module-chat-completion"},{"type":"function","doc":"Chat with a Mistral model. Send messages and get a completion from the model.","title":"Mistral.chat/2","ref":"Mistral.html#chat/2"},{"type":"function","doc":"* `:model` (`t:String.t/0`) - Required. The model to use for generating the response.\n* `:messages` (list of `t:map/0`) - Required. List of messages in the conversation.\n* `:temperature` (`t:float/0`) - Controls randomness. Lower values are more deterministic (0.0 to 1.5).\n* `:top_p` (`t:float/0`) - Controls diversity via nucleus sampling. Considers only tokens with the top_p probability mass. The default value is `1.0`.\n* `:max_tokens` (`t:non_neg_integer/0`) - Maximum number of tokens to generate.\n* `:stream` - When true, returns a stream of partial response chunks. The default value is `false`.\n* `:random_seed` (`t:non_neg_integer/0`) - Seed for deterministic results.\n* `:tools` (list of `t:map/0`) - List of tools available to the model.\n* `:tool_choice` - Controls tool selection. Options: 'auto', 'any', 'none', or a specific tool.\n* `:presence_penalty` (`t:float/0`) - Penalizes repetition of tokens. Higher values reduce repetition. The default value is `0.0`.\n* `:frequency_penalty` (`t:float/0`) - Penalizes tokens based on their frequency. Higher values reduce repetition. The default value is `0.0`.\n* `:safe_prompt` (`t:boolean/0`) - Whether to inject a safety prompt before all conversations. The default value is `false`.","title":"Options - Mistral.chat/2","ref":"Mistral.html#chat/2-options"},{"type":"function","doc":"Each message is a map with the following fields:\n\n* `:role` - Required. The role of the message, either `system`, `user`, `assistant` or `tool`.\n* `:content` - The content of the message.\n* `:tool_calls` - *(optional)* Tool calls from the assistant that the model wants to use.\n* `:tool_call_id` (`t:String.t/0`) - *(optional)* Required when `role` is 'tool'. ID of the tool call this message is responding to.","title":"Message structure - Mistral.chat/2","ref":"Mistral.html#chat/2-message-structure"},{"type":"function","doc":"Each tool is a map with the following fields:\n\n* `:type` - Required. The type of tool. Currently only 'function' is supported.\n* `:function` (`t:map/0`) - Required. The function definition.\n  * `:name` (`t:String.t/0`) - Required. The name of the function to be called.\n  * `:description` (`t:String.t/0`) - *(optional)* A description of what the function does.\n  * `:parameters` - Required. The parameters the function accepts, described as a JSON Schema object.","title":"Tool structure - Mistral.chat/2","ref":"Mistral.html#chat/2-tool-structure"},{"type":"function","doc":"iex> Mistral.chat(client, [\n    ...>   model: \"mistral-small-latest\",\n    ...>   messages: [\n    ...>     %{role: \"user\", content: \"Write a haiku.\"}\n    ...>   ]\n    ...> ])\n    {:ok, %{\"choices\" => [%{\"message\" => %{\"content\" => \"Nature's whisper soft...\"}}], ...}}\n\n    # Stream the response\n    iex> {:ok, stream} = Mistral.chat(client, [\n    ...>   model: \"mistral-small-latest\",\n    ...>   messages: [%{role: \"user\", content: \"Write a haiku.\"}],\n    ...>   stream: true\n    ...> ])\n    iex> Enum.to_list(stream)\n    [%{\"choices\" => [%{\"delta\" => ...}]}, ...]","title":"Examples - Mistral.chat/2","ref":"Mistral.html#chat/2-examples"},{"type":"function","doc":"iex> Mistral.chat(client, [\n    ...>   model: \"mistral-large-latest\",\n    ...>   messages: [%{role: \"user\", content: \"What is the weather?\"}],\n    ...>   tools: [\n    ...>     %{\n    ...>       type: \"function\",\n    ...>       function: %{\n    ...>         name: \"get_weather\",\n    ...>         description: \"Fetches current weather\",\n    ...>         parameters: %{type: \"object\", properties: %{}}\n    ...>       }\n    ...>     }\n    ...>   ],\n    ...>   tool_choice: \"auto\"\n    ...> ])","title":"Tool Example - Mistral.chat/2","ref":"Mistral.html#chat/2-tool-example"},{"type":"type","doc":"Client struct","title":"Mistral.client/0","ref":"Mistral.html#t:client/0"},{"type":"function","doc":"Generate embeddings for the given input using a specified model.","title":"Mistral.embed/2","ref":"Mistral.html#embed/2"},{"type":"function","doc":"* `:model` (`t:String.t/0`) - The model to use for generating embeddings. The default value is `\"mistral-embed\"`.\n* `:input` - Required. Text or list of texts to generate embeddings for.","title":"Options - Mistral.embed/2","ref":"Mistral.html#embed/2-options"},{"type":"function","doc":"iex> Mistral.embed(client, input: \"Hello, world!\")\n    {:ok, %{\"data\" => [%{\"embedding\" => [...]}]}}\n\n    iex> Mistral.embed(client, input: [\"First text\", \"Second text\"])\n    {:ok, %{\"data\" => [%{\"embedding\" => [...]}, %{\"embedding\" => [...]}]}}","title":"Examples - Mistral.embed/2","ref":"Mistral.html#embed/2-examples"},{"type":"function","doc":"Creates a new Mistral API client using the API key set in your application's config.\n\n```elixir\nconfig :mistral, :api_key, \"your-api-key\"\n```\n\nIf given, a keyword list of options will be passed to `Req.new/1`.","title":"Mistral.init/0","ref":"Mistral.html#init/0"},{"type":"function","doc":"iex> client = Mistral.init()\n    %Mistral{}\n\n    iex> client = Mistral.init(headers: [{\"X-Custom-Header\", \"value\"}])\n    %Mistral{}","title":"Examples - Mistral.init/0","ref":"Mistral.html#init/0-examples"},{"type":"function","doc":"","title":"Mistral.init/1","ref":"Mistral.html#init/1"},{"type":"function","doc":"Creates a new Mistral API client with the given API key.\n\nOptionally, a keyword list of options can be passed through to `Req.new/1`.","title":"Mistral.init/2","ref":"Mistral.html#init/2"},{"type":"function","doc":"iex> client = Mistral.init(\"YOUR_API_KEY\")\n    %Mistral{}\n\n    iex> client = Mistral.init(\"YOUR_API_KEY\", receive_timeout: :infinity)\n    %Mistral{}","title":"Examples - Mistral.init/2","ref":"Mistral.html#init/2-examples"},{"type":"type","doc":"Client response","title":"Mistral.response/0","ref":"Mistral.html#t:response/0"},{"type":"exception","doc":"Exception raised when the Mistral API returns an error.","title":"Mistral.APIError","ref":"Mistral.APIError.html"}],"proglang":"elixir","content_type":"text/markdown","producer":{"name":"ex_doc","version":"0.37.3"}}